<script setup>
import { getCurrentInstance, ref, nextTick } from 'vue';
import { get, post } from '@/utils/request.js'
import * as Icons from "@ant-design/icons-vue";
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';
const context = getCurrentInstance()?.appContext.config.globalProperties;
const components = {
    ...Icons,
};

const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {
    name: null
}
let formData = ref(initFormData);
const treeData = ref(null);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/menu/save' : '/api/menu/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

defineExpose({
    open,
    formData,
    initFormData,
    treeData,
    isSave,
})

</script>

<script>
export default {
    name: '菜单管理'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" name="menu" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item label="上级菜单" name="parentId" style="width: 250px;"
                    :rules="[{ required: true, message: '上级菜单不能为空!' }]">
                    <a-tree-select v-model:value="formData.parentId" show-search style="width: 100%"
                        :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                        :placeholder="formatMessage('page.input', '请输入')" allow-clea tree-data-simple-mode
                        :tree-data="treeData" tree-node-filter-prop="name" :field-names="{
                            children: 'children',
                            label: 'name',
                            value: 'id',
                        }">
                        <template #title="{ value: id, name }">
                            {{ name }}
                        </template>
                    </a-tree-select>
                </a-form-item>
                <a-form-item label="菜单名称" name="name" style="width: 250px;"
                    :rules="[{ required: true, message: '菜单名称不能为空!' }]">
                    <a-input v-model:value="formData.name" />
                </a-form-item>
                <a-form-item label="路由地址" name="route" style="width: 250px;">
                    <a-input v-model:value="formData.route" />
                </a-form-item>
                <a-form-item label="页面组件" name="component" style="width: 250px;">
                    <a-input v-model:value="formData.component" />
                </a-form-item>
                <a-form-item label="类型" name="type" style="width: 250px;"
                    :rules="[{ required: true, message: '类型不能为空!' }]">
                    <a-select ref="select" v-model:value="formData.type" :options="[
                        { label: '菜单', value: 0 },
                        { label: '按钮', value: 1 },
                    ]"></a-select>
                </a-form-item>
                <a-form-item v-if="formData.type == 0" label="菜单图标" name="icon" style="width: 250px;">
                    <a-input v-model:value="formData.icon" />
                </a-form-item>
                <a-form-item v-else label="权限" name="icon" style="width: 250px;">
                    <a-input v-model:value="formData.authority" />
                </a-form-item>
                <a-form-item label="国际化ID" name="icon" style="width: 250px;">
                    <a-input v-model:value="formData.languageId" />
                </a-form-item>
                <a-form-item label="排序" name="sort" style="width: 250px;">
                    <a-input v-model:value="formData.sort" />
                </a-form-item>
                <a-form-item label="状态" name="status" style="width: 250px;">
                    <a-select ref="select" v-model:value="formData.status" :options="[
                        { label: '禁用', value: 0 },
                        { label: '正常', value: 1 },
                    ]"></a-select>
                </a-form-item>
                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>